@@ -2,13 +2,19 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time
+import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time, random, threading
 
 # inc imports.
 import cl1
 from fil3s import Files, Formats
 
 # fyunctions.
+def get_argument(id):
+	match = False
+	for i in sys.argv:
+		if id == i: match = True
+		elif match == True: return i
+	return None
 def __get_operating_system__():
 	os = platform.system().lower()
 	if os in ["darwin"]: return "osx"
@@ -32,24 +38,29 @@ def __save_file__(path, data):
 	file = open(path, "w+") 
 	file.write(data)
 	file.close()
-def __check_alias__( 
+def __check_alias__(
 	# the source name.
 	alias=None, 
 	# the source path.
 	executable=None,
 ):
+	present = "--create-alias" in sys.argv and get_argument("--create-alias") == alias
 	path = f"/usr/local/bin/{alias}"
-	if not os.path.exists(path) or '--create-alias' in sys.argv:
+	if present or not os.path.exists(path):
 		file = f"""package={executable}/\nargs=""\nfor var in "$@" ; do\n   	if [ "$args" == "" ] ; then\n   		args=$var\n   	else\n   		args=$args" "$var\n   	fi\ndone\npython3 $package $args\n"""
 		os.system(f"sudo touch {path}")
 		os.system(f"sudo chmod 755 {path}")
 		os.system(f"sudo chown {USER}:{GROUP} {path}")
-		Files.File(path=f"{path}", data=file).save()
+		try:
+			Files.File(path=f"{path}", data=file).save()
+		except:
+			print(f"Unable to create alias $ {alias}.")
+			return None
 		os.system(f"sudo chmod 755 {path}")
 		if '--silent' not in sys.argv:
 			print(f'Successfully created alias: {alias}.')
 			print(f"Check out the docs for more info $: {alias} -h")
-	if '--create-alias' in sys.argv:
+	if present:
 		quit()
 
 # source.
