@@ -6,12 +6,12 @@ from syst3m.v1.classes.config import *
 import platform 
 
 # functions.
-def get_argument(id):
+def get_argument(id, empty=None):
 	match = False
 	for i in sys.argv:
 		if id == i: match = True
 		elif match == True: return i
-	return None
+	return empty
 class Defaults(object):
 	def __init__(self):
 
@@ -38,15 +38,18 @@ class Defaults(object):
 		# the source path.
 		executable=None,
 	):
-		id = get_argument("--create-alias")
-		present = "--create-alias" in sys.argv and id == ALIAS
+		present = "--create-alias" in sys.argv and get_argument("--create-alias") == alias
 		path = f"/usr/local/bin/{alias}"
 		if present or not os.path.exists(path):
 			file = f"""package={executable}/\nargs=""\nfor var in "$@" ; do\n   	if [ "$args" == "" ] ; then\n   		args=$var\n   	else\n   		args=$args" "$var\n   	fi\ndone\npython3 $package $args\n"""
 			os.system(f"sudo touch {path}")
 			os.system(f"sudo chmod 755 {path}")
 			os.system(f"sudo chown {self.user}:{self.group} {path}")
-			Files.File(path=f"{path}", data=file).save()
+			try:
+				Files.File(path=f"{path}", data=file).save()
+			except:
+				print(f"Unable to create alias $ {alias}.")
+				return None
 			os.system(f"sudo chmod 755 {path}")
 			if '--silent' not in sys.argv:
 				print(f'Successfully created alias: {alias}.')
